/*
* Copyright 2008 Patrick Oosterveld - patrick.oosterveld@gmail.com
*
* This source is distributed under the terms of the GNU PUBLIC LICENSE version 3
* http://www.gnu.org/licenses/gpl.html
*/

package com.googlepages.dronten.jtagger.gui;

import javax.swing.*;
import java.awt.*;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.io.File;


/**
 * Image previewer.
 */
public class ImagePreview extends JComponent implements PropertyChangeListener {
    private static final long   serialVersionUID = 1;
    private ImageIcon   aThumbnail = null;
    private File        aFile = null;


    /**
     *
     * @param fc
     */
    public ImagePreview(JFileChooser fc) {
        setPreferredSize(new Dimension(100, 50));
        fc.addPropertyChangeListener(this);
    }


    /**
     *
     */
    public void loadImage() {
        if (aFile == null) {
            aThumbnail = null;
            return;
        }

        //Don't use createImageIcon (which is a wrapper for getResource)
        //because the image we're trying to load is probably not one
        //of this program's own resources.
        ImageIcon tmpIcon = new ImageIcon(aFile.getPath());

        if (tmpIcon.getIconWidth() > 90) {
            aThumbnail = new ImageIcon(tmpIcon.getImage().getScaledInstance(90, -1, Image.SCALE_DEFAULT));
        }
        else { //no need to miniaturize
            aThumbnail = tmpIcon;
        }
    }


    /**
     *
     * @param e
     */
    public void propertyChange(PropertyChangeEvent e) {
        boolean update = false;
        String prop = e.getPropertyName();

        if (JFileChooser.DIRECTORY_CHANGED_PROPERTY.equals(prop)) { // If the directory changed, don't show an image.
            aFile = null;
            update = true;
        }
        else if (JFileChooser.SELECTED_FILE_CHANGED_PROPERTY.equals(prop)) { // If a file became selected, find out which one.
            aFile = (File) e.getNewValue();
            update = true;
        }

        //Update the preview accordingly.
        if (update) {
            aThumbnail = null;

            if (isShowing()) {
                loadImage();
                repaint();
            }
        }
    }


    /**
     *
     * @param g
     */
    protected void paintComponent(Graphics g) {
        if (aThumbnail == null) {
            loadImage();
        }

        if (aThumbnail != null) {
            int x = getWidth() / 2 - aThumbnail.getIconWidth() / 2;
            int y = getHeight() / 2 - aThumbnail.getIconHeight() / 2;

            if (y < 0) {
                y = 0;
            }

            if (x < 5) {
                x = 5;
            }

            aThumbnail.paintIcon(this, g, x, y);
        }
    }

}
