/*
* Copyright 2004 - 2009 by dronten@gmail.com
*
* This source is distributed under the terms of the GNU PUBLIC LICENSE version 3
* http://www.gnu.org/licenses/gpl.html
*/

package com.googlepages.dronten.jtagger.gui.dlg;

import com.googlepages.dronten.jtagger.JTagger;

import javax.swing.*;
import java.awt.*;


/**
 * Base dialog object.<br>
 * Implements common usable routines for dialog windows.
 */
public abstract class BaseDialog extends JDialog {
    /**
     * Create dialog.
     *
     * @param owner     Set to null to create a window that can hide below application.
     * @param title     Dialog title
     * @param modal     true for modal operation
     * @throws HeadlessException
     */
    public BaseDialog(JFrame owner, String title, boolean modal) throws HeadlessException {
        super(owner, title, modal);
        setDefaultCloseOperation(DISPOSE_ON_CLOSE);

        addWindowListener(new java.awt.event.WindowAdapter() {
            public void windowClosing(java.awt.event.WindowEvent e) {
                close();
                setVisible(false);
                dispose();
            }
        });

        setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
    }


    /**
     * Center dialog on application window.
     */
    public void centerOnApplication() {
        Point winPos = JTagger.get().getLocation();
        Dimension winSize = JTagger.get().getSize();
        Dimension dlgSize = getSize();

        double x = winPos.getX() + (winSize.width / 2);
        double y = winPos.getY() + (winSize.height / 2);

        x -= (dlgSize.width / 2);
        y -= (dlgSize.height / 2);
        setLocation(new Point((int) x, (int) y));
    }


    /**
     * Center dialog on screen.
     */
    public void centerOnScreen() {
        Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        Dimension dlgSize = getSize();
        Point newPos = new Point((screenSize.width / 2) - (dlgSize.width / 2), (screenSize.height / 2) - (dlgSize.height / 2));
        setLocation(newPos);
    }


    /**
     *
     */
    public void close() {
    }


    /**
     * Center dialog on parent window.
     */
    public void leftOnParent() {
        Point windowPos = this.getOwner().getLocation();
        setLocation(windowPos);
    }
}